@@ -6,12 +6,20 @@
 #' @export
 #' 
 #' @example /inst/examples/example_getCranDescription.R
-getCranDescription <- function(pkg, repos=getOption("repos"), type="source", path, pkgs = pkgDep(pkg, repos=repos, type=type)){
+getCranDescription <- function(pkg, repos = getOption("repos"), 
+                               type = "source", 
+                               pkgs = pkgDep(pkg, repos=repos, type=type)){
 
   getOne <- function(package){
-    url <- sprintf("http://cran.r-project.org/web/packages/%s/index.html", package)
+    repos <- repos[[1]]
+    if(!grepl("/$", repos)) repos <- paste0(repos, "/")
+    
+    url <- gsub("https://", "http://", 
+                sprintf("%sweb/packages/%s/index.html", repos, package)
+    )
     x <- tryCatch({
-      readHTMLTable(url, header=FALSE, which=1, stringsAsFactors=FALSE)
+      text <- paste(readLines(url), collapse = "\n")
+      XML::readHTMLTable(text, header=FALSE, which=1, stringsAsFactors=FALSE)
     }, error=function(e) e
     )
     if(inherits(x, "error")) {
